% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/est_model.R
\name{est_mcblog}
\alias{est_mcblog}
\title{Misclassification Corrected Logistic Regression for Bilateral Disease Data}
\usage{
est_mcblog(
  z1_star,
  z2_star,
  z1,
  z2,
  formula,
  formula_delta,
  formula_sens,
  formula_spec,
  data,
  control = list(maxit = 5000, trace = 0)
)
}
\arguments{
\item{z1_star}{vector of error-prone binary response observations of entity 1 of length n, NA if missing}

\item{z2_star}{vector of error-prone binary response observations of entity 2 of length n, NA if missing}

\item{z1}{vector of binary gold-standard response observations of entity 1 of length n, NA if missing}

\item{z2}{vector of binary gold-standard response observations of entity 2 of length n, NA if missing}

\item{formula}{a formula specifying the design matrix of the logistic regression model
with worse-entity response max(z1,z2) as in \code{\link[stats]{model.matrix}}}

\item{formula_delta}{a formula specifying the design matrix for modeling delta (probability of disease
in both entities, given disease)}

\item{formula_sens}{a formula specifying the person-specific design matrix for modeling the
sensitivity of the error-prone entity-specific observation process}

\item{formula_spec}{a formula specifying the person-specific design matrix for modeling the
specificity of the error-prone entity-specific observation process}

\item{data}{a data.frame with n rows including all terms used in the model formulas}

\item{control}{list of control parameters for the numerical likelihood optimization as
in \code{\link[stats]{optim}}}
}
\description{
Estimate logistic regression for binary worse-entity response defined as
y=max(z_1, z_2) based on error-prone single entity disease classifications z1_star and
z2_star and gold standard classifications z1 and z2 for a validation subset of individuals.
4 different conditional probabilities are modeled: (i) the conditional probability of
worse-entity disease, and (ii) the probability of disease in both entities given disease.
Furthermore, (iii) the sensitivity and (iv) the specificity of the entity-specific
classification process, i.e. P(Z*=1|Z=1), and P(Z*=0|Z=0).
We model all conditional probabilities based on the logistic function, corresponding to a standard
logistic regression for worse-entity.
Estimation is based on optimization of a likelihood where each of the n observation contributes
depending on the available outcome data, i.e. a subset of (z1, z2, z1.star, z2.star).
}
